==> gspiceui-v0.8.90.tar.gz: gspiceui-v0.8.90/src/gnucap/PnlGnuCapOP.hpp <==
//*****************************************************************************
//                                PnlGnuCapOP.hpp                             *
//                               -----------------                            *
//  Description : This class derives from the Analysis Panel base class and   *
//                provides a GUI for a user to configure a Operating Point    *
//                Analysis for GNU-Cap electronic circuit simulator.          *
//  Started     : 06/11/2003                                                  *
//  Last Update : 14/07/2005                                                  *
//  Copyright   : (C) 2003 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PNLGNUCAPOP_HPP
#define PNLGNUCAPOP_HPP

// System Includes


// wxWindows Library Includes


// Application Includes

#include "base/PnlAnaBase.hpp"

// Local Constant Declarations

//*****************************************************************************

class PnlGnuCapOP : public PnlAnaBase
{
  public:

    // Enumerated type for specifying the step scale
    enum  eScaleType
    {
      eSCALE_LIN,
      eSCALE_LOG,

      eSCALE_FST = eSCALE_LIN,
      eSCALE_LST = eSCALE_LOG
    };

  private:

    // Temperature sweep scale
    wxRadioBox  m_oRbxScale;

    void  Create( void );
    bool  bSetScale( eScaleType eScale );

  public:

    PnlGnuCapOP( wxWindow * poWin );
    ~PnlGnuCapOP( );

    bool  bClear( void );

    bool  bLoad  ( Simulation & roSim );
    bool  bReload( Simulation & roSim );
    bool  bSave  ( Simulation & roSim );

    // Event handlers
    void  OnScale  ( wxCommandEvent & roEvtCmd );
    void  OnSrcCpnt( wxCommandEvent & roEvtCmd );

    // In order to be able to react to a menu command, it must be given a
    // unique identifier such as a const or an enum.
    enum ePnlItemID
    {
      ID_RBX_SCALE = PnlAnaBase::ID_LST+1,

      ID_UNUSED,      // Assigned to controls for which events are not used

      ID_FST = ID_RBX_SCALE,
      ID_LST = ID_RBX_SCALE
    };

    // Leave this as the last line as private access is envoked by macro
    DECLARE_EVENT_TABLE( )
};

//*****************************************************************************

#endif // PNLGNUCAPOP_HPP

==> gspiceui-v0.9.33.tar.gz: gspiceui-v0.9.33/src/gnucap/PnlGnuCapOP.hpp <==
//*****************************************************************************
//                                PnlGnuCapOP.hpp                             *
//                               -----------------                            *
//  Description : This class derives from the Analysis Panel base class and   *
//                provides a GUI for a user to configure a Operating Point    *
//                Analysis for GNU-Cap electronic circuit simulator.          *
//  Started     : 06/11/2003                                                  *
//  Last Update : 14/07/2005                                                  *
//  Copyright   : (C) 2003 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef PNLGNUCAPOP_HPP
#define PNLGNUCAPOP_HPP

// System Includes


// wxWindows Library Includes


// Application Includes

#include "base/PnlAnaBase.hpp"

// Local Constant Declarations

//*****************************************************************************

class PnlGnuCapOP : public PnlAnaBase
{
  public:

    // Enumerated type for specifying the step scale
    enum  eScaleType
    {
      eSCALE_LIN,
      eSCALE_LOG,
      eSCALE_DEC,

      eSCALE_FST = eSCALE_LIN,
      eSCALE_LST = eSCALE_DEC
    };

  private:

    // Temperature sweep scale
    wxRadioBox  m_oRbxScale;

    void  Create( void );
    bool  bSetScale( eScaleType eScale );

  public:

    PnlGnuCapOP( wxWindow * poWin );
    ~PnlGnuCapOP( );

    bool  bClear( void );

    bool  bLoad  ( Simulation & roSim );
    bool  bReload( Simulation & roSim );
    bool  bSave  ( Simulation & roSim );

    // Event handlers
    void  OnScale  ( wxCommandEvent & roEvtCmd );
    void  OnSrcCpnt( wxCommandEvent & roEvtCmd );

    // In order to be able to react to a menu command, it must be given a
    // unique identifier such as a const or an enum.
    enum ePnlItemID
    {
      ID_RBX_SCALE = PnlAnaBase::ID_LST+1,

      ID_UNUSED,      // Assigned to controls for which events are not used

      ID_FST = ID_RBX_SCALE,
      ID_LST = ID_RBX_SCALE
    };

    // Leave this as the last line as private access is envoked by macro
    DECLARE_EVENT_TABLE( )
};

//*****************************************************************************

#endif // PNLGNUCAPOP_HPP
